photoshop.colors package
========================

Submodules
----------

photoshop.colors.cmyk module
----------------------------

.. automodule:: photoshop.colors.cmyk
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.colors.hsb module
---------------------------

.. automodule:: photoshop.colors.hsb
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.colors.lab module
---------------------------

.. automodule:: photoshop.colors.lab
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.colors.rgb module
---------------------------

.. automodule:: photoshop.colors.rgb
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: photoshop.colors
   :members:
   :undoc-members:
   :show-inheritance:
